@@ -1,6 +1,6 @@
 # - coding: utf-8 -
 
-# Copyright (C) 2007-2009 Toms Bauģis <toms.baugis at gmail.com>
+# Copyright (C) 2007-2010 Toms Bauģis <toms.baugis at gmail.com>
 # Copyright (C) 2007-2009 Patryk Zawadzki <patrys at pld-linux.org>
 # Copyright (C) 2008 Pēteris Caune <cuu508 at gmail.com>
 
@@ -35,7 +35,6 @@ from configuration import conf, runtime, dialogs
 
 import stuff
 import keybinder
-from hamsterdbus import HAMSTER_URI, HamsterDbusController
 
 # controllers for other windows
 import widgets
@@ -199,7 +198,7 @@ class HamsterApplet(object):
         self._gui = stuff.load_ui_file("applet.ui")
         self.window = self._gui.get_object('hamster-window')
         # on close don't destroy the popup, just hide it instead
-        self.window.connect("delete_event", lambda *args: self.__show_toggle(None, False))
+        self.window.connect("delete_event", lambda *args: self.__show_toggle(False))
 
         self.new_name = widgets.ActivityEntry()
         self.new_name.connect("value-entered", self.on_switch_activity_clicked)
@@ -225,12 +224,9 @@ class HamsterApplet(object):
         # DBus Setup
         try:
             dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
-            name = dbus.service.BusName(HAMSTER_URI, dbus.SessionBus())
-            self.dbusController = HamsterDbusController(bus_name = name)
-
             # Set up connection to the screensaver
-            self.dbusIdleListener = idle.DbusIdleListener(runtime.dispatcher)
-            runtime.dispatcher.add_handler('active_changed', self.on_idle_changed)
+            self.dbusIdleListener = idle.DbusIdleListener()
+            self.dbusIdleListener.connect('idle-changed', self.on_idle_changed)
 
         except dbus.DBusException, e:
             logging.error("Can't init dbus: %s" % e)
@@ -244,22 +240,18 @@ class HamsterApplet(object):
         self.hotkey = conf.get("keybinding")
         self.bind_hotkey()
 
-        runtime.dispatcher.add_handler('conf_changed', self.on_conf_changed)
+        conf.connect('conf-changed', self.on_conf_changed)
 
         # Load today's data, activities and set label
         self.last_activity = None
         self.load_day()
         self.update_label()
 
-        # Hamster DBusController current fact initialising
-        self.__update_fact()
 
         # refresh hamster every 60 seconds to update duration
         gobject.timeout_add_seconds(60, self.refresh_hamster)
-
-        runtime.dispatcher.add_handler('panel_visible', self.__show_toggle)
-        runtime.dispatcher.add_handler('activity_updated', self.after_activity_update)
-        runtime.dispatcher.add_handler('day_updated', self.after_fact_update)
+        runtime.storage.connect('activities-changed',self.after_activity_update)
+        runtime.storage.connect('facts-changed',self.after_fact_update)
 
         self.screen = None
         if self.workspace_tracking:
@@ -349,7 +341,7 @@ class HamsterApplet(object):
         dialogs.edit.show(self.applet, activity_id = self.last_activity['id'])
 
     def switch_cb(self, n, action):
-        self.__show_toggle(None, not self.button.get_active())
+        self.__show_toggle(not self.button.get_active())
 
 
     def load_day(self):
@@ -447,18 +439,7 @@ class HamsterApplet(object):
         fact = self.treeview.get_selected_fact()
         runtime.storage.remove_fact(fact["id"])
 
-    def __update_fact(self):
-        """dbus controller current fact updating"""
-        last_activity_id = 0
-
-        if not self.last_activity:
-            self.dbusController.TrackingStopped()
-        else:
-            last_activity_id = self.last_activity['id']
-
-        self.dbusController.FactUpdated(last_activity_id)
-
-    def __show_toggle(self, event, is_active):
+    def __show_toggle(self, is_active):
         """main window display and positioning"""
         self.button.set_active(is_active)
 
@@ -521,7 +502,7 @@ class HamsterApplet(object):
 
     """events"""
     def on_toggle(self, widget):
-        self.__show_toggle(None, self.button.get_active())
+        self.__show_toggle(self.button.get_active())
 
 
     def on_todays_keys(self, tree, event):
@@ -543,7 +524,7 @@ class HamsterApplet(object):
                                      ", ".join(fact["tags"]),
                                      category_name = fact["category"],
                                      description = fact["description"])
-            runtime.dispatcher.dispatch('panel_visible', False)
+            self.__show_toggle(False)
 
 
     def on_windows_keys(self, tree, event_key):
@@ -552,13 +533,13 @@ class HamsterApplet(object):
               and event_key.state & gtk.gdk.CONTROL_MASK)):
             if self.new_name.popup.get_property("visible") == False \
                and self.new_tags.popup.get_property("visible") == False:
-                runtime.dispatcher.dispatch('panel_visible', False)
+                self.__show_toggle(False)
                 return True
         return False
 
     """button events"""
     def on_overview(self, menu_item):
-        runtime.dispatcher.dispatch('panel_visible', False)
+        self.__show_toggle(False)
         dialogs.overview.show(self.applet)
 
     def show_overview(self, menu_item, verb):
@@ -571,20 +552,19 @@ class HamsterApplet(object):
         dialogs.about.show()
 
     def show_preferences(self, menu_item, verb):
-        runtime.dispatcher.dispatch('panel_visible', False)
+        self.__show_toggle(False)
         dialogs.prefs.show(self.applet)
 
 
     """signals"""
-    def after_activity_update(self, widget, renames):
+    def after_activity_update(self, widget):
         self.new_name.refresh_activities()
         self.load_day()
         self.update_label()
 
-    def after_fact_update(self, event, date):
+    def after_fact_update(self, event):
         self.load_day()
         self.update_label()
-        self.__update_fact()
 
     def on_idle_changed(self, event, state):
         # state values: 0 = active, 1 = idle
@@ -596,8 +576,7 @@ class HamsterApplet(object):
         elif self.timeout_enabled and self.last_activity and \
              self.last_activity['end_time'] is None:
 
-            runtime.storage.touch_fact(self.last_activity,
-                                       end_time = self.dbusIdleListener.getIdleFrom())
+            runtime.storage.stop_tracking(self.dbusIdleListener.getIdleFrom())
 
     def on_workspace_changed(self, screen, previous_workspace):
         if not previous_workspace:
@@ -631,7 +610,7 @@ class HamsterApplet(object):
             if parsed_activity:
                 category_id = None
                 if parsed_activity.category_name:
-                    category_id = runtime.storage.get_category_by_name(parsed_activity.category_name)
+                    category_id = runtime.storage.get_category_id(parsed_activity.category_name)
 
                 activity = runtime.storage.get_activity_by_name(parsed_activity.activity_name,
                                                                 category_id,
@@ -675,12 +654,10 @@ class HamsterApplet(object):
 
     """global shortcuts"""
     def on_keybinding_activated(self):
-        self.__show_toggle(None, not self.button.get_active())
+        self.__show_toggle(not self.button.get_active())
 
 
-    def on_conf_changed(self, event, data):
-        key, value = data
-
+    def on_conf_changed(self, event, key, value):
         if key == "enable_timeout":
             self.timeout_enabled = value
         elif key == "notify_on_idle":
@@ -720,12 +697,12 @@ class HamsterApplet(object):
                                  self.new_tags.get_text().decode("utf8", "replace"))
         self.new_name.set_text("")
         self.new_tags.set_text("")
-        runtime.dispatcher.dispatch('panel_visible', False)
+        self.__show_toggle(False)
 
     def on_stop_tracking_clicked(self, widget):
-        runtime.storage.touch_fact(self.last_activity)
+        runtime.storage.stop_tracking()
         self.last_activity = None
-        runtime.dispatcher.dispatch('panel_visible', False)
+        self.__show_toggle(False)
 
     def on_window_size_request(self, window, event):
         box = self.window.get_allocation()
